@@ -7,6 +7,7 @@ from act.qc.qcfilter import parse_bit, set_bit, unset_bit
 import numpy as np
 import pytest
 import copy
+import dask.array as da
 
 
 def test_fft_shading_test():
@@ -41,12 +42,14 @@ def test_arm_qc():
         ran = True
         obj.attrs['_datastream'] = obj.attrs['datastream']
         del obj.attrs['datastream']
-        obj2 = add_dqr_to_qc(obj, variable=variable)
+        obj2 = add_dqr_to_qc(obj, variable=variable, add_qc_variable=qc_variable)
+        obj3 = add_dqr_to_qc(obj)
+        add_dqr_to_qc(obj, variable=variable, exclude=['D190529.4'])
+        add_dqr_to_qc(obj, variable=variable, include=['D400101.1'])
         with np.testing.assert_raises(ValueError):
             del obj.attrs['_datastream']
             add_dqr_to_qc(obj, variable=variable)
 
-        obj4 = add_dqr_to_qc(obj)
     except ValueError:
         ran = False
 
@@ -63,11 +66,11 @@ def test_arm_qc():
         assert 'Suspect' not in obj2[qc_variable].attrs['flag_assessments']
         assert 'Incorrect' not in obj2[qc_variable].attrs['flag_assessments']
 
-        assert qc_variable in obj4
-        dqr = [True for d in obj4[qc_variable].attrs['flag_meanings'] if 'D190529.4' in d]
+        assert qc_variable in obj3
+        dqr = [True for d in obj3[qc_variable].attrs['flag_meanings'] if 'D190529.4' in d]
         assert dqr[0] is True
-        assert 'Suspect' not in obj4[qc_variable].attrs['flag_assessments']
-        assert 'Incorrect' not in obj4[qc_variable].attrs['flag_assessments']
+        assert 'Suspect' not in obj3[qc_variable].attrs['flag_assessments']
+        assert 'Incorrect' not in obj3[qc_variable].attrs['flag_assessments']
 
 
 def test_qcfilter():
@@ -75,6 +78,11 @@ def test_qcfilter():
     var_name = 'inst_up_long_dome_resist'
     expected_qc_var_name = 'qc_' + var_name
 
+    ds_object.qcfilter.check_for_ancillary_qc(
+        var_name, add_if_missing=True, cleanup=False, flag_type=False)
+    assert expected_qc_var_name in list(ds_object.keys())
+    del ds_object[expected_qc_var_name]
+
     # Perform adding of quality control variables to object
     result = ds_object.qcfilter.add_test(var_name, test_meaning='Birds!')
     assert isinstance(result, dict)
@@ -130,13 +138,14 @@ def test_qcfilter():
     ds_object.qcfilter.unset_test(var_name, index=0,
                                   test_number=result['test_number'])
     # Remove the test
-    ds_object.qcfilter.remove_test(var_name,
-                                   test_number=result['test_number'])
+    ds_object.qcfilter.remove_test(var_name, test_number=33)
+    ds_object.qcfilter.remove_test(var_name, test_number=result['test_number'])
     pytest.raises(ValueError, ds_object.qcfilter.add_test, var_name)
     pytest.raises(ValueError, ds_object.qcfilter.remove_test, var_name)
 
     ds_object.close()
 
+    assert np.all(parse_bit([257]) == np.array([1, 9], dtype=np.int32))
     pytest.raises(ValueError, parse_bit, [1, 2])
     pytest.raises(ValueError, parse_bit, -1)
 
@@ -210,6 +219,44 @@ def test_qcfilter():
     ds_object.close()
 
 
+def test_qcfilter2():
+    ds_object = read_netcdf(EXAMPLE_IRT25m20s)
+    var_name = 'inst_up_long_dome_resist'
+    expected_qc_var_name = 'qc_' + var_name
+
+    data = ds_object[var_name].values
+    data[0:4] = data[0:4] + 30.
+    data[1000:1024] = data[1000:1024] + 30.
+    ds_object[var_name].values = data
+
+    coef = 1.4
+    ds_object.qcfilter.add_iqr_test(var_name, coef=1.4, test_assessment='Bad', prepend_text='arm')
+    assert np.sum(ds_object[expected_qc_var_name].values) == 28
+    assert ds_object[expected_qc_var_name].attrs['flag_masks'] == [1]
+    assert ds_object[expected_qc_var_name].attrs['flag_meanings'] == [
+        f'arm: Value outside of interquartile range test range with a coefficient of {coef}']
+
+    ds_object.qcfilter.add_iqr_test(var_name, test_number=3, prepend_text='ACT')
+    assert np.sum(ds_object[expected_qc_var_name].values) == 140
+    assert ds_object[expected_qc_var_name].attrs['flag_masks'] == [1, 4]
+    assert ds_object[expected_qc_var_name].attrs['flag_meanings'][-1] == (
+        'ACT: Value outside of interquartile range test range with a coefficient of 1.5')
+
+    ds_object.qcfilter.add_gesd_test(var_name, test_assessment='Bad')
+    assert np.sum(ds_object[expected_qc_var_name].values) == 204
+    assert ds_object[expected_qc_var_name].attrs['flag_masks'] == [1, 4, 8]
+    assert ds_object[expected_qc_var_name].attrs['flag_meanings'][-1] == (
+        'Value failed generalized Extreme Studentized Deviate test with an alpha of 0.05')
+
+    ds_object.qcfilter.add_gesd_test(var_name, alpha=0.1)
+    assert np.sum(ds_object[expected_qc_var_name].values) == 332
+    assert ds_object[expected_qc_var_name].attrs['flag_masks'] == [1, 4, 8, 16]
+    assert ds_object[expected_qc_var_name].attrs['flag_meanings'][-1] == (
+        'Value failed generalized Extreme Studentized Deviate test with an alpha of 0.1')
+    assert ds_object[expected_qc_var_name].attrs['flag_assessments'] == [
+        'Bad', 'Indeterminate', 'Bad', 'Indeterminate']
+
+
 def test_qctests():
     ds_object = read_netcdf(EXAMPLE_IRT25m20s)
     var_name = 'inst_up_long_dome_resist'
@@ -217,17 +264,23 @@ def test_qctests():
     # Add in one missing value and test for that missing value
     data = ds_object[var_name].values
     data[0] = np.nan
-    ds_object[var_name].values = data
+    ds_object[var_name].data = da.from_array(data)
     result = ds_object.qcfilter.add_missing_value_test(var_name)
     data = ds_object.qcfilter.get_masked_data(var_name,
                                               rm_tests=result['test_number'])
     assert data.mask[0]
 
+    result = ds_object.qcfilter.add_missing_value_test(var_name, use_dask=True)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'], return_index=True)
+    assert data == np.array([0])
+    ds_object.qcfilter.remove_test(var_name, test_number=result['test_number'])
+
     # less than min test
     limit_value = 6.8
-    result = ds_object.qcfilter.add_less_test(var_name, limit_value, prepend_text='arm')
-    data = ds_object.qcfilter.get_masked_data(var_name,
-                                              rm_tests=result['test_number'])
+    result = ds_object.qcfilter.add_less_test(var_name, limit_value, prepend_text='arm',
+                                              limit_attr_name='fail_min')
+
+    data = ds_object.qcfilter.get_masked_data(var_name, rm_tests=result['test_number'])
     assert 'arm' in result['test_meaning']
     assert np.ma.count_masked(data) == 54
     assert 'fail_min' in ds_object[result['qc_variable_name']].attrs.keys()
@@ -238,11 +291,19 @@ def test_qctests():
     result = ds_object.qcfilter.add_less_test(var_name, limit_value, test_assessment='Suspect')
     assert 'warn_min' in ds_object[result['qc_variable_name']].attrs.keys()
 
+    limit_value = 8
+    result = ds_object.qcfilter.add_less_test(var_name, limit_value)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'], return_index=True)
+    assert np.sum(data) == 2911939
+    result = ds_object.qcfilter.add_less_test(var_name, limit_value, use_dask=True)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'], return_index=True)
+    assert np.sum(data) == 2911939
+
     # greator than max test
     limit_value = 12.7
-    result = ds_object.qcfilter.add_greater_test(var_name, limit_value, prepend_text='arm')
-    data = ds_object.qcfilter.get_masked_data(var_name,
-                                              rm_tests=result['test_number'])
+    result = ds_object.qcfilter.add_greater_test(var_name, limit_value, prepend_text='arm',
+                                                 limit_attr_name='fail_max')
+    data = ds_object.qcfilter.get_masked_data(var_name, rm_tests=result['test_number'])
     assert 'arm' in result['test_meaning']
     assert np.ma.count_masked(data) == 61
     assert 'fail_max' in ds_object[result['qc_variable_name']].attrs.keys()
@@ -253,11 +314,19 @@ def test_qctests():
     result = ds_object.qcfilter.add_greater_test(var_name, limit_value, test_assessment='Suspect')
     assert 'warn_max' in ds_object[result['qc_variable_name']].attrs.keys()
 
+    result = ds_object.qcfilter.add_greater_test(var_name, limit_value, use_dask=True)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'], return_index=True)
+    assert np.sum(data) == 125458
+    result = ds_object.qcfilter.add_greater_test(var_name, limit_value)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'], return_index=True)
+    assert np.sum(data) == 125458
+
     # less than or equal test
     limit_value = 6.9
     result = ds_object.qcfilter.add_less_equal_test(var_name, limit_value,
                                                     test_assessment='Suspect',
-                                                    prepend_text='arm')
+                                                    prepend_text='arm',
+                                                    limit_attr_name='warn_min')
     data = ds_object.qcfilter.get_masked_data(var_name,
                                               rm_tests=result['test_number'])
     assert 'arm' in result['test_meaning']
@@ -270,11 +339,20 @@ def test_qctests():
     result = ds_object.qcfilter.add_less_equal_test(var_name, limit_value)
     assert 'fail_min' in ds_object[result['qc_variable_name']].attrs.keys()
 
+    result = ds_object.qcfilter.add_less_equal_test(var_name, limit_value, use_dask=True)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'], return_index=True)
+    assert np.sum(data) == 601581
+    result = ds_object.qcfilter.add_less_equal_test(var_name, limit_value)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'], return_index=True)
+    assert np.sum(data) == 601581
+
     # greater than or equal test
+    result = ds_object.qcfilter.add_greater_equal_test(var_name, None)
     limit_value = 12
     result = ds_object.qcfilter.add_greater_equal_test(var_name, limit_value,
                                                        test_assessment='Suspect',
-                                                       prepend_text='arm')
+                                                       prepend_text='arm',
+                                                       limit_attr_name='warn_max')
     data = ds_object.qcfilter.get_masked_data(var_name,
                                               rm_tests=result['test_number'])
     assert 'arm' in result['test_meaning']
@@ -287,11 +365,20 @@ def test_qctests():
     result = ds_object.qcfilter.add_greater_equal_test(var_name, limit_value)
     assert 'fail_max' in ds_object[result['qc_variable_name']].attrs.keys()
 
+    result = ds_object.qcfilter.add_greater_equal_test(var_name, limit_value, use_dask=True)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'],
+                                               return_index=True)
+    assert np.sum(data) == 1189873
+    result = ds_object.qcfilter.add_greater_equal_test(var_name, limit_value)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'],
+                                               return_index=True)
+    assert np.sum(data) == 1189873
+
     # equal to test
     limit_value = 7.6705
-    result = ds_object.qcfilter.add_equal_to_test(var_name, limit_value, prepend_text='arm')
-    data = ds_object.qcfilter.get_masked_data(var_name,
-                                              rm_tests=result['test_number'])
+    result = ds_object.qcfilter.add_equal_to_test(var_name, limit_value, prepend_text='arm',
+                                                  limit_attr_name='fail_equal_to')
+    data = ds_object.qcfilter.get_masked_data(var_name, rm_tests=result['test_number'])
     assert 'arm' in result['test_meaning']
     assert np.ma.count_masked(data) == 2
     assert 'fail_equal_to' in ds_object[result['qc_variable_name']].attrs.keys()
@@ -303,11 +390,21 @@ def test_qctests():
                                                   test_assessment='Indeterminate')
     assert 'warn_equal_to' in ds_object[result['qc_variable_name']].attrs.keys()
 
+    result = ds_object.qcfilter.add_equal_to_test(var_name, limit_value, use_dask=True)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'],
+                                               return_index=True)
+    assert np.sum(data) == 8631
+    result = ds_object.qcfilter.add_equal_to_test(var_name, limit_value)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'],
+                                               return_index=True)
+    assert np.sum(data) == 8631
+
     # not equal to test
     limit_value = 7.6705
     result = ds_object.qcfilter.add_not_equal_to_test(var_name, limit_value,
                                                       test_assessment='Indeterminate',
-                                                      prepend_text='arm')
+                                                      prepend_text='arm',
+                                                      limit_attr_name='warn_not_equal_to')
     data = ds_object.qcfilter.get_masked_data(var_name,
                                               rm_tests=result['test_number'])
     assert 'arm' in result['test_meaning']
@@ -320,11 +417,21 @@ def test_qctests():
     result = ds_object.qcfilter.add_not_equal_to_test(var_name, limit_value)
     assert 'fail_not_equal_to' in ds_object[result['qc_variable_name']].attrs.keys()
 
+    result = ds_object.qcfilter.add_not_equal_to_test(var_name, limit_value, use_dask=True)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'],
+                                               return_index=True)
+    assert np.sum(data) == 9320409
+    result = ds_object.qcfilter.add_not_equal_to_test(var_name, limit_value)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'],
+                                               return_index=True)
+    assert np.sum(data) == 9320409
+
     # outside range test
     limit_value1 = 6.8
     limit_value2 = 12.7
-    result = ds_object.qcfilter.add_outside_test(var_name, limit_value1, limit_value2,
-                                                 prepend_text='arm')
+    result = ds_object.qcfilter.add_outside_test(
+        var_name, limit_value1, limit_value2, prepend_text='arm',
+        limit_attr_names=['fail_lower_range', 'fail_upper_range'])
     data = ds_object.qcfilter.get_masked_data(var_name,
                                               rm_tests=result['test_number'])
     assert 'arm' in result['test_meaning']
@@ -343,11 +450,26 @@ def test_qctests():
     assert 'warn_lower_range' in ds_object[result['qc_variable_name']].attrs.keys()
     assert 'warn_upper_range' in ds_object[result['qc_variable_name']].attrs.keys()
 
+    result = ds_object.qcfilter.add_outside_test(var_name, limit_value1, limit_value2,
+                                                 use_dask=True)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'],
+                                               return_index=True)
+    assert np.sum(data) == 342254
+    result = ds_object.qcfilter.add_outside_test(var_name, limit_value1, limit_value2,)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'],
+                                               return_index=True)
+    assert np.sum(data) == 342254
+
+    # Starting to run out of space for tests. Remove some tests.
+    for ii in range(16, 30):
+        ds_object.qcfilter.remove_test(var_name, test_number=ii)
+
     # inside range test
     limit_value1 = 7
     limit_value2 = 8
-    result = ds_object.qcfilter.add_inside_test(var_name, limit_value1, limit_value2,
-                                                prepend_text='arm')
+    result = ds_object.qcfilter.add_inside_test(
+        var_name, limit_value1, limit_value2, prepend_text='arm',
+        limit_attr_names=['fail_lower_range_inner', 'fail_upper_range_inner'])
     data = ds_object.qcfilter.get_masked_data(var_name,
                                               rm_tests=result['test_number'])
     assert 'arm' in result['test_meaning']
@@ -368,9 +490,20 @@ def test_qctests():
     assert 'warn_lower_range_inner' in ds_object[result['qc_variable_name']].attrs.keys()
     assert 'warn_upper_range_inner' in ds_object[result['qc_variable_name']].attrs.keys()
 
+    result = ds_object.qcfilter.add_inside_test(var_name, limit_value1, limit_value2,
+                                                use_dask=True)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'],
+                                               return_index=True)
+    assert np.sum(data) == 1820693
+    result = ds_object.qcfilter.add_inside_test(var_name, limit_value1, limit_value2,)
+    data = ds_object.qcfilter.get_qc_test_mask(var_name, result['test_number'],
+                                               return_index=True)
+    assert np.sum(data) == 1820693
+
     # delta test
     test_limit = 0.05
-    result = ds_object.qcfilter.add_delta_test(var_name, test_limit, prepend_text='arm')
+    result = ds_object.qcfilter.add_delta_test(var_name, test_limit, prepend_text='arm',
+                                               limit_attr_name='warn_delta')
     data = ds_object.qcfilter.get_masked_data(var_name,
                                               rm_tests=result['test_number'])
     assert 'arm' in result['test_meaning']
@@ -382,17 +515,26 @@ def test_qctests():
 
     data = ds_object.qcfilter.get_masked_data(var_name,
                                               rm_assessments=['Suspect', 'Bad'])
-    assert np.ma.count_masked(data) == 4320
+    assert np.ma.count_masked(data) == 1355
 
     result = ds_object.qcfilter.add_delta_test(var_name, test_limit, test_assessment='Bad')
     assert 'fail_delta' in ds_object[result['qc_variable_name']].attrs.keys()
 
     comp_object = read_netcdf(EXAMPLE_IRT25m20s)
+    with np.testing.assert_raises(ValueError):
+        result = ds_object.qcfilter.add_difference_test(var_name, 'test')
+
+    with np.testing.assert_raises(ValueError):
+        result = ds_object.qcfilter.add_difference_test(
+            var_name, {comp_object.attrs['datastream']: comp_object},
+            var_name, diff_limit=None)
+
+    assert ds_object.qcfilter.add_difference_test(var_name, set_test_regardless=False) is None
+
     result = ds_object.qcfilter.add_difference_test(
         var_name, {comp_object.attrs['datastream']: comp_object},
         var_name, diff_limit=1, prepend_text='arm')
-    data = ds_object.qcfilter.get_masked_data(var_name,
-                                              rm_tests=result['test_number'])
+    data = ds_object.qcfilter.get_masked_data(var_name, rm_tests=result['test_number'])
     assert 'arm' in result['test_meaning']
     assert not (data.mask).all()
 
@@ -597,3 +739,27 @@ def test_compare_time_series_trends():
                         'temp_mean with temp_mean off by 3600 seconds exceeding absolute '
                         'threshold of 900 seconds.')
     assert ds[qc_var_name].attrs['flag_meanings'][-1] == test_description
+
+
+def test_qc_data_type():
+    drop_vars = ['base_time', 'time_offset', 'inst_up_long_case_resist',
+                 'inst_up_long_hemisp_tp', 'inst_up_short_hemisp_tp',
+                 'inst_sfc_ir_temp', 'lat', 'lon', 'alt']
+    ds_object = read_netcdf(EXAMPLE_IRT25m20s, drop_variables=drop_vars)
+    var_name = 'inst_up_long_dome_resist'
+    expected_qc_var_name = 'qc_' + var_name
+    ds_object.qcfilter.check_for_ancillary_qc(var_name, add_if_missing=True)
+    del ds_object[expected_qc_var_name].attrs['flag_meanings']
+    del ds_object[expected_qc_var_name].attrs['flag_assessments']
+    ds_object[expected_qc_var_name] = ds_object[expected_qc_var_name].astype(np.int8)
+    ds_object.qcfilter.add_test(var_name, index=[1], test_number=9, test_meaning='First test')
+
+    assert ds_object[expected_qc_var_name].attrs['flag_masks'][0].dtype == np.uint32
+    assert ds_object[expected_qc_var_name].dtype == np.int16
+    ds_object.qcfilter.add_test(var_name, index=[1], test_number=17, test_meaning='Second test')
+    assert ds_object[expected_qc_var_name].dtype == np.int32
+    ds_object.qcfilter.add_test(var_name, index=[1], test_number=33, test_meaning='Third test')
+    assert ds_object[expected_qc_var_name].dtype == np.int64
+    assert ds_object[expected_qc_var_name].attrs['flag_masks'][0].dtype == np.uint64
+
+    ds_object.qcfilter.add_test(var_name, index=[1], test_meaning='Fourth test', recycle=True)
