@@ -3,6 +3,7 @@
 import act
 import numpy as np
 import xarray as xr
+import glob
 
 
 def test_get_stability_indices():
@@ -11,7 +12,8 @@ def test_get_stability_indices():
 
     try:
         sonde_ds = act.retrievals.calculate_stability_indicies(
-            sonde_ds, temp_name="tdry", td_name="dp", p_name="pres")
+            sonde_ds, temp_name="tdry", td_name="dp", p_name="pres",
+            rh_name='rh')
         metpy = True
     except ImportError:
         metpy = False
@@ -19,11 +21,10 @@ def test_get_stability_indices():
     if metpy is True:
         np.testing.assert_allclose(
             sonde_ds["parcel_temperature"].values[0:5],
-            [269.85000005, 269.74530704, 269.67805708,
-             269.62251119, 269.57241322], rtol=1e-5)
+            [269.85, 269.745276, 269.678006, 269.622444, 269.572331], rtol=1e-5)
         assert sonde_ds["parcel_temperature"].attrs["units"] == "kelvin"
         np.testing.assert_almost_equal(
-            sonde_ds["surface_based_cape"], 1.62, decimal=2)
+            sonde_ds["surface_based_cape"], 0.62, decimal=2)
         assert sonde_ds["surface_based_cape"].attrs["units"] == "J/kg"
         assert sonde_ds[
             "surface_based_cape"].attrs["long_name"] == "Surface-based CAPE"
@@ -189,3 +190,62 @@ def test_calculate_sirs_variable():
 
     sirs_object.close()
     met_object.close()
+
+
+def test_calculate_pbl_liu_liang():
+    files = glob.glob(act.tests.sample_files.EXAMPLE_TWP_SONDE_20060121)
+    files2 = glob.glob(act.tests.sample_files.EXAMPLE_SONDE1)
+    files += files2
+    files.sort()
+
+    pblht = []
+    pbl_regime = []
+    for i, r in enumerate(files):
+        obj = act.io.armfiles.read_netcdf(r)
+        obj['tdry'].attrs['units'] = 'degree_Celsius'
+        obj = act.retrievals.sonde.calculate_pbl_liu_liang(obj, smooth_height=10)
+        pblht.append(float(obj['pblht_liu_liang'].values))
+        pbl_regime.append(obj['pblht_regime_liu_liang'].values)
+
+    assert pbl_regime == ['NRL', 'NRL', 'NRL', 'NRL', 'NRL']
+    np.testing.assert_array_almost_equal(pblht, [847.5, 858.2, 184.8, 197.7, 443.2], decimal=1)
+
+    obj = act.io.armfiles.read_netcdf(files[1])
+    obj['tdry'].attrs['units'] = 'degree_Celsius'
+    obj = act.retrievals.sonde.calculate_pbl_liu_liang(obj, land_parameter=False)
+    np.testing.assert_almost_equal(obj['pblht_liu_liang'].values, 733.6, decimal=1)
+
+    obj = act.io.armfiles.read_netcdf(files[-2:])
+    obj['tdry'].attrs['units'] = 'degree_Celsius'
+    with np.testing.assert_raises(ValueError):
+        obj = act.retrievals.sonde.calculate_pbl_liu_liang(obj)
+
+    obj = act.io.armfiles.read_netcdf(files[0])
+    obj['tdry'].attrs['units'] = 'degree_Celsius'
+    temp = obj['tdry'].values
+    temp[10:20] = 19.
+    temp[0:10] = -10
+    obj['tdry'].values = temp
+    obj = act.retrievals.sonde.calculate_pbl_liu_liang(obj, land_parameter=False)
+    assert obj['pblht_regime_liu_liang'].values == 'SBL'
+
+    with np.testing.assert_raises(ValueError):
+        obj2 = obj.where(obj['alt'] < 1000., drop=True)
+        obj2 = act.retrievals.sonde.calculate_pbl_liu_liang(obj2, smooth_height=15)
+
+    with np.testing.assert_raises(ValueError):
+        obj2 = obj.where(obj['pres'] < 200., drop=True)
+        obj2 = act.retrievals.sonde.calculate_pbl_liu_liang(obj2, smooth_height=15)
+
+    with np.testing.assert_raises(ValueError):
+        temp[0:5] = -40
+        obj['tdry'].values = temp
+        obj = act.retrievals.sonde.calculate_pbl_liu_liang(obj)
+
+    obj = act.io.armfiles.read_netcdf(files[0])
+    obj['tdry'].attrs['units'] = 'degree_Celsius'
+    temp = obj['tdry'].values
+    temp[20:50] = 100.
+    obj['tdry'].values = temp
+    with np.testing.assert_raises(ValueError):
+        obj = act.retrievals.sonde.calculate_pbl_liu_liang(obj)
